==> dvdisaster_0.72.4.orig.tar.bz2: dvdisaster-0.72.4/documentation/ru/howtos11.php <==
<?php
# dvdisaster: English homepage translation
# Copyright (C) 2004-2012 Carsten Gnörlich
#
# UTF-8 trigger: äöüß 
#
# Include our PHP sub routines, then call begin_page()
# to start the HTML page, insert the header, 
# navigation and news if appropriate.

require("../include/dvdisaster.php");
require("../include/screenshot.php");
begin_page();

howto_headline("Поиск ошибок на носителях", "Основные настройки", "images/scan-icon.png");
?>

<!-- Insert actual page content below -->

<?php begin_screen_shot("Открытие диалога настроек.","global-prefs-invoke.png"); ?>
<table><tr><td class="valignt"><img src="../images/prefs-icon.png" alt="dvdisaster UI: Preferences (button)" class="valignb"></td>
<td>В диалоге настроек имеются следующие вкладки.
Откройте диалог, выбрав значок, отмеченный зеленым на снимке с экрана
(для увеличения картинки нажмите на нее). Этот значок может выглядеть по-разному,
в зависимости от используемой темы.</td>
</tr></table>
<?php end_screen_shot(); ?>

<?php begin_screen_shot("Вкладка \"Образ\".","scan-prefs-image.png"); ?>
<b>Вкладка "Привод".</b> Важно выбрать правильный метод определения размера образа.
Вариант "ISO/UDF" (отмечен зеленым) обычно работает в любой ситуации.
Выбирайте "ECC/RS02" (отмечено красным), только если есть уверенность, что носитель 
содержит данные для исправления ошибок по методу RS02. Использование данных для исправления ошибок (ecc) улучшит результаты сканирования, но поиск несуществующих ecc-данных будет стоить нескольких минут. <p>
Остальные настройки установите так, как показано на снимке.<p>
<?php end_screen_shot(); ?>

<pre> </pre>

<?php begin_screen_shot("Вкладка \"Привод\".","scan-prefs-drive.png"); ?>
<b>Вкладка "Привод".</b> Чтение данных во время раскручивания привода
может создать ложные сообщения об ошибках. Чтобы dvdisaster выждал нужное время, настройте время
раскручивания в соответствии со своим приводом (обычно 5-10 секунд) в поле, помеченном зеленым.<p>
Остальные параметры оставьте так, как показано на картинке; их можно <a href="howtos14.php">оптимизировать</a> позднее.<p>
<?php end_screen_shot(); ?>

<pre> </pre>

<?php begin_screen_shot("Вкладка \"Попытки чтения\".","scan-prefs-read-attempts.png"); ?>
<b>Вкладка "Попытки чтения".</b> Установите параметры для попыток чтения так, как здесь показано.
Использование более высоких значений приведет к ненужной интенсивности чтения, но не улучшит результаты.
Для параметра "Чтение и анализ необработанных секторов" (первая зеленая пометка) используется C2-анализ и, возможно, привод передает больше сырых данных для получения более точной оценки качества CD-носителя. Эта настройка ничего не делает в случае носителей DVD и BD, но она спокойно может оставаться активированной, если только не вызывает проблем при чтении вашим приводом CD-дисков.
После ошибки чтения следует пропустить не менее 16 секторов (вторая зеленая пометка);
при сканировании сильно поврежденных носителей эта настройка может быть 
<a href="howtos14.php">оптимизирована в сторону увеличения</a>.<br>
В время проверки носителя не рекомендуется делать многократные попытки чтения; установите число попыток в 1 в трех местах, помеченных оранжевым. Накопление необработанных секторов тоже должно быть выключено во время сканирования.<p>
<?php end_screen_shot(); ?>

<pre> </pre>

<?php begin_screen_shot("Вкладка \"Разное\".","general-prefs-misc.png"); ?>
<b>Вкладка "Разное".</b> В настоящее время у этой вкладки есть лишь функции для создания журналов. Это полезно для отправки <a href="feedback.php">отчетов об ошибках</a>
, но во время нормальной работы это следует отключать.
<?php end_screen_shot(); ?>

<pre> </pre>

<b>Не используемые вкладки</b><p>

Вкладки "Коррекция ошибок" и "Файлы" не имеют значения при проверке носителей.
Вкладка "Внешний вид" дает возможность переделывать цвета вывода по своему вкусу, 
но это не влияет на сам процесс проверки носителей.

<pre> </pre>


<a href="howtos12.php">Выполнение проверки...</a>


<!-- do not change below -->

<?php
# end_page() adds the footer line and closes the HTML properly.

end_page();
?>

==> dvdisaster_0.79.3.orig.tar.bz2: dvdisaster-0.79.3/documentation/ru/howtos11.php <==
<?php
# dvdisaster: English homepage translation
# Copyright (C) 2004-2010 Carsten Gnörlich
#
# UTF-8 trigger: äöüß 
#
# Include our PHP sub routines, then call begin_page()
# to start the HTML page, insert the header, 
# navigation and news if appropriate.

require("../include/dvdisaster.php");
require("../include/screenshot.php");
begin_page();

howto_headline("Поиск ошибок на носителях", "Основные настройки", "images/scan-icon.png");
?>

<!--- Insert actual page content below --->

<?php begin_screen_shot("Открытие диалога настроек.","global-prefs-invoke.png"); ?>
<table><tr><td valign="top"><img src="../images/prefs-icon.png" valign="bottom"></td>
<td>В диалоге настроек имеются следующие вкладки.
Откройте диалог, выбрав значок, отмеченный зеленым на снимке с экрана
(для увеличения картинки нажмите на нее). Этот значок может выглядеть по-разному,
в зависимости от используемой темы.</td>
</tr></table>
<?php end_screen_shot(); ?>

<?php begin_screen_shot("Вкладка \"Образ\".","scan-prefs-image.png"); ?>
<b>Вкладка "Привод".</b> Важно выбрать правильный метод определения размера образа.
Вариант "ISO/UDF" (отмечен зеленым) обычно работает в любой ситуации.
Выбирайте "ECC/RS02" (отмечено красным), только если есть уверенность, что носитель 
содержит данные для исправления ошибок по методу RS02. Использование данных для исправления ошибок (ecc) улучшит результаты сканирования, но поиск несуществующих ecc-данных будет стоить нескольких минут. <p>
Остальные настройки установите так, как показано на снимке.<p>
<?php end_screen_shot(); ?>

<pre> </pre>

<?php begin_screen_shot("Вкладка \"Привод\".","scan-prefs-drive.png"); ?>
<b>Вкладка "Привод".</b> Чтение данных во время раскручивания привода
может создать ложные сообщения об ошибках. Чтобы dvdisaster выждал нужное время, настройте время
раскручивания в соответствии со своим приводом (обычно 5-10 секунд) в поле, помеченном зеленым.<p>
Остальные параметры оставьте так, как показано на картинке; их можно <a href="howtos14.php">оптимизировать</a> позднее.<p>
<?php end_screen_shot(); ?>

<pre> </pre>

<?php begin_screen_shot("Вкладка \"Попытки чтения\".","scan-prefs-read-attempts.png"); ?>
<b>Вкладка "Попытки чтения".</b> Установите параметры для попыток чтения так, как здесь показано.
Использование более высоких значений приведет к ненужной интенсивности чтения, но не улучшит результаты.
Для параметра "Чтение и анализ необработанных секторов" (первая зеленая пометка) используется C2-анализ и, возможно, привод передает больше сырых данных для получения более точной оценки качества CD-носителя. Эта настройка ничего не делает в случае носителей DVD и BD, но она спокойно может оставаться активированной, если только не вызывает проблем при чтении вашим приводом CD-дисков.
После ошибки чтения следует пропустить не менее 16 секторов (вторая зеленая пометка);
при сканировании сильно поврежденных носителей эта настройка может быть 
<a href="howtos14.php">оптимизирована в сторону увеличения</a>.<br>
В время проверки носителя не рекомендуется делать многократные попытки чтения; установите число попыток в 1 в трех местах, помеченных оранжевым. Накопление необработанных секторов тоже должно быть выключено во время сканирования.<p>
<?php end_screen_shot(); ?>

<pre> </pre>

<?php begin_screen_shot("Вкладка \"Разное\".","general-prefs-misc.png"); ?>
<b>Вкладка "Разное".</b> В настоящее время у этой вкладки есть лишь функции для создания журналов. Это полезно для отправки <a href="feedback.php">отчетов об ошибках</a>
, но во время нормальной работы это следует отключать.
<?php end_screen_shot(); ?>

<pre> </pre>

<b>Не используемые вкладки</b><p>

Вкладки "Коррекция ошибок" и "Файлы" не имеют значения при проверке носителей.
Вкладка "Внешний вид" дает возможность переделывать цвета вывода по своему вкусу, 
но это не влияет на сам процесс проверки носителей.

<pre> </pre>


<a href="howtos12.php">Выполнение проверки...</a>


<!--- do not change below --->

<?php
# end_page() adds the footer line and closes the HTML properly.

end_page();
?>
